from setuptools import setup, find_packages
import setuptools_scm

setup(
    name='icloudservice',  # Replace with your library name
    use_scm_version=True,
    setup_requires=["setuptools>=42", "setuptools_scm"],
    packages=find_packages(include=['icloudservice', 'icloudservice.*']),
    install_requires=[
        'boto3',  # AWS SDK for Python
        'rich', # Progress bar library
    ],
    description='The `icloudservice` class provides a Python interface for interacting with',
    long_description=open('README.md').read(),  # Long description from README
    long_description_content_type='text/markdown',  # Type of long description
    author='Leonardo Daniel Gonzalo Laura',  # Replace with your name
    author_email='glleonardodaniel@gmail.com',  # Replace with your email
    url='https://github.com/leonardogonzalolaura/workspace_icloudservice',  # Replace with your project URL
    license='MIT',  # Replace with the license you choose
)




import platform
import importlib.metadata
from dataclasses import dataclass
from rich.console import Console
from rich.logging import RichHandler

# Get the Python version
python_version = platform.python_version()

@dataclass
class Service():
    console = Console()

    def info(self):
        try:
            version = importlib.metadata.version('icloudservice')
        except importlib.metadata.PackageNotFoundError:
            version = 'unknown'
        # Get class name
        service_name = 'Cloud integration services for AWS and AZURE'
        log_message = (
        f"[yellow]Version library:[/yellow] [cyan]{version}[/cyan] \n"
        f"[yellow]Name:[/yellow] [cyan]icloudservice[/cyan] \n"
        f"[yellow]Description:[/yellow] [cyan]{service_name}[/cyan] \n"
        f"[yellow]Python Version:[/yellow] [cyan]{python_version}[/cyan] \n"
        )
        self.console.print(log_message)